mot.cl\_routines.filters package
================================

Submodules
----------

mot.cl\_routines.filters.base module
------------------------------------

.. automodule:: mot.cl_routines.filters.base
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl\_routines.filters.gaussian module
----------------------------------------

.. automodule:: mot.cl_routines.filters.gaussian
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl\_routines.filters.mean module
------------------------------------

.. automodule:: mot.cl_routines.filters.mean
    :members:
    :undoc-members:
    :show-inheritance:

mot.cl\_routines.filters.median module
--------------------------------------

.. automodule:: mot.cl_routines.filters.median
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mot.cl_routines.filters
    :members:
    :undoc-members:
    :show-inheritance:
